@@ -18,15 +18,18 @@ from tql.pipe import reduce_mem_usage, cprint
 
 
 class AutoFeat(object):
+    vt = vt
 
-    def __init__(self, df, entity_id, type2features, index=None, time_index=None, secondary_time_index=None):
-        self.entity_id = entity_id  # 表名
-        self.type2features = type2features
-        self.index = '__id' if index is None else index  # 索引列不能当target_entity
+    def __init__(self, df, base_entity_id, target_entity_id, type2features, index=None, time_index=None,
+                 secondary_time_index=None):
+        self.entity_id = base_entity_id  # 表名
+        self.type2features = self._convert_type(type2features)
+        self.index = '__id' if index is None else index
+        self.target_entity_id = target_entity_id  # self.index != '__id' => self.target_entity_id = self.entity_id
 
         self.es = ft.EntitySet(id='MAIN')
         self.es.entity_from_dataframe(
-            entity_id=entity_id,
+            entity_id=self.entity_id,
             dataframe=df.copy(),
             index=self.index,
             variable_types=self.variable_types,
@@ -34,32 +37,27 @@ class AutoFeat(object):
             secondary_time_index=secondary_time_index
         )
 
-        print(self.es)
-
-    def dfs(self, target_entity=None, max_depth=1, features_only=True, n_jobs=1, chunk_size=None,
-            ignore_variables=['uid']):
-        """Deep Feature Synthesis"""
-        if self.index != '__id':
-            target_entity = self.entity_id
-            cprint(f"target_entity == base_entity_id: {self.entity_id} !!!")
-        else:
-            assert target_entity is not None
+        self._create_es()
 
+    def _create_es(self):
+        """overwrite"""
         for col in tqdm(self.normalize_entity_cols, desc='Normalize Entity'):
             self.es.normalize_entity(self.entity_id, col, col)
 
-        return self.run_dfs(self.es, target_entity, max_depth, chunk_size, n_jobs, features_only, ignore_variables)
+    def run_dfs(self, max_depth=1, features_only=True, chunk_size=None, n_jobs=1, ignore_variables=None):
+        """Deep Feature Synthesis"""
+        if ignore_variables is None:
+            ignore_variables = [self.target_entity_id]  # ['uid']
 
-    def run_dfs(self, es, target_entity, max_depth, chunk_size, n_jobs, features_only, ignore_variables):
         _ = ft.dfs(
-            entityset=es,
-            target_entity=target_entity,  # 具有唯一ID: 不重复id的base_es或者normalize_entity生成的唯一id es
+            entityset=self.es,
+            target_entity=self.target_entity_id,  # 具有唯一ID: 不重复id的base_es或者normalize_entity生成的唯一id es
+            features_only=features_only,
             max_depth=max_depth,
-            verbose=1,
+            ignore_variables={self.entity_id: ignore_variables},
             chunk_size=chunk_size,
             n_jobs=n_jobs,
-            ignore_variables={self.entity_id: ignore_variables},
-            features_only=features_only,
+            verbose=1,
         )
 
         if features_only:
@@ -84,9 +82,15 @@ class AutoFeat(object):
             dic.update(zip(features, len(features) * [type_]))
         return dic
 
-    @property
-    def vt(self):
-        return vt
+    def _convert_type(self, type2features):
+        type2features_ = {}
+        for type_, features in type2features.items():
+            if isinstance(type_, str):
+                type2features_[vt.__getattribute__(type_)] = features
+            else:
+                type2features_[type_] = features
+
+        return type2features_
 
 
 if __name__ == '__main__':
@@ -99,8 +103,7 @@ if __name__ == '__main__':
         vt.Categorical: ['a', 'b']
     }
 
-    af = AutoFeat(df, 'test', type2features)
+    af = AutoFeat(df, 'test', 'test', type2features)
     # af = AutoFeat(df, 'test', type2features, index='uid')  # base_entity 就是 base_entity_id
 
-    af.dfs('uid')
-    af.es.plot()
+    af.run_dfs(max_depth=2)
