@@ -17,6 +17,7 @@ class LGBMClassifierOOF(BaseOOF):
 
     def __init__(self, X, y, params=None, **kwargs):
         super().__init__(X, y, **kwargs)
+
         self.params = params
 
     def fit_predict(self, X_train, y_train, X_valid, y_valid, X_test, **kwargs):
@@ -25,13 +26,18 @@ class LGBMClassifierOOF(BaseOOF):
             clf.set_params(**self.params)
             # print(clf.get_params())
 
-        clf.fit(X_train, y_train,
-                eval_set=[(X_train, y_train), (X_valid, y_valid)],
-                eval_names=('Train', 'Valid'),
-                verbose=True,
-                early_stopping_rounds=None  # fit_params
-                )
+        self.clf = clf.fit(
+            X_train, y_train,
+            eval_set=[(X_train, y_train), (X_valid, y_valid)],
+            eval_names=('Train', 'Valid'),
+            verbose=100,
+            early_stopping_rounds=100  # fit_params
+        )
 
-        valid_predict = clf.predict_proba(X_valid)[:, 1]
-        test_predict = clf.predict_proba(X_test)[:, 1]
+        valid_predict = clf.predict_proba(X_valid)
+        test_predict = clf.predict_proba(X_test)
         return valid_predict, test_predict
+
+    def plot_feature_importances(self):
+        # TODO
+        pass
